@@ -5,15 +5,15 @@ use strict;
 use vars qw(
     @ISA @EXPORT $VERSION
     $Headless $SortKeys $SingleQuote
-    $ImplicitTyping $ImplicitUnicode 
+    $ImplicitBinary $ImplicitTyping $ImplicitUnicode 
     $UseCode $LoadCode $DumpCode
     $DeparseObject
 );
-use 5.00307;
+use 5.006;
 use Exporter;
 
 BEGIN {
-    $VERSION = '1.00';
+    $VERSION = '1.07_01';
     @EXPORT  = qw( Dump Load DumpFile LoadFile );
     @ISA     = qw( Exporter );
 
@@ -137,10 +137,6 @@ __END__
 
 YAML::Syck - Fast, lightweight YAML loader and dumper
 
-=head1 VERSION
-
-This document describes version 1.00 of YAML::Syck, released December 10, 2007.
-
 =head1 SYNOPSIS
 
     use YAML::Syck;
@@ -251,7 +247,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2005, 2006, 2007 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2005-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This software is released under the MIT license cited below.
 
